@@ -15,7 +15,7 @@ import tarfile
 from os.path import join as pjoin, normpath
 
 from jupyter_core.paths import (
-    jupyter_data_dir, jupyter_config_dir, jupyter_config_path,
+    jupyter_data_dir, jupyter_config_dir, jupyter_config_path, jupyter_path,
     SYSTEM_JUPYTER_PATH, ENV_JUPYTER_PATH, ENV_CONFIG_PATH, SYSTEM_CONFIG_PATH
 )
 from ipython_genutils.path import ensure_dir_exists
@@ -27,8 +27,6 @@ from traitlets.utils.importstring import import_item
 
 from tornado.log import LogFormatter
 
-from .semver import satisfies
-
 
 # Constants for pretty print extension listing function.
 # Window doesn't support coloring in the commandline
@@ -38,8 +36,7 @@ RED_X = '\033[31mX\033[0m' if os.name != 'nt' else 'X'
 GREEN_ENABLED = '\033[32menabled \033[0m' if os.name != 'nt' else 'enabled '
 RED_DISABLED = '\033[31mdisabled\033[0m' if os.name != 'nt' else 'disabled'
 
-
-CONFIG_NAME = 'jupyterlab_config'
+CONFIG_DIR = 'labconfig'
 
 #------------------------------------------------------------------------------
 # Public API
@@ -124,6 +121,7 @@ def install_labextension(path, name, overwrite=False, symlink=False,
     full_dest = None
 
     labext = _get_labextension_dir(user=user, sys_prefix=sys_prefix, prefix=prefix, labextensions_dir=labextensions_dir)
+
     # make sure labextensions dir exists
     ensure_dir_exists(labext)
     
@@ -282,18 +280,15 @@ def _set_labextension_state(name, state,
         The name of the python module associated with the extension.
     """
     user = False if sys_prefix else user
-    cfg = _read_config_data(user=user, sys_prefix=sys_prefix)
+    extensions = _read_config_data('labextensions', user=user,
+                                   sys_prefix=sys_prefix)
     if logger:
         logger.info("{} extension {}...".format(
             "Enabling" if state else "Disabling",
             name
         ))
-    labextensions = (
-        cfg.setdefault("LabApp", {})
-        .setdefault("labextensions", {})
-    )
 
-    old_state = labextensions.get(name, None)
+    old_state = extensions.get(name, None)
     if old_state is None:
         old_state = dict(enabled=False)
     elif isinstance(old_state, bool):
@@ -307,12 +302,13 @@ def _set_labextension_state(name, state,
         else:
             logger.info(u"Disabling: %s" % (name))
 
-    labextensions[name] = dict(
+    extensions[name] = dict(
         enabled=new_enabled,
         python_module=python_module
     )
 
-    _write_config_data(cfg, user=user, sys_prefix=sys_prefix, logger=logger)
+    _write_config_data('labextensions', extensions, user=user,
+                       sys_prefix=sys_prefix, logger=logger)
 
     if new_enabled:
         full_dest = find_labextension(name)
@@ -460,7 +456,7 @@ def find_labextension(name):
     name : str
         The name of the extension.
     """
-    for exts in _labextension_dirs():
+    for exts in jupyter_path('labextensions'):
         full_dest = os.path.join(exts, name)
         if os.path.exists(full_dest):
             return full_dest
@@ -501,18 +497,6 @@ def validate_labextension_folder(name, full_dest, logger=None):
                 if not os.path.exists(path):
                     has_files.append("File in manifest does not exist: {}".format(path))
 
-        for (mod, deps) in manifest.get('modules', {}).items():
-            # ignore jupyterlab modules since
-            # they are only semver compatibile with their own version
-            if mod.startswith('jupyterlab@'):
-                continue
-            for dep in deps:
-                if dep.startswith('jupyterlab@'):
-                    dep = dep.split('/')[0].split('@')[-1]
-                    if not satisfies(__version__, dep, False):
-                        version_compatible.append('Expects JupyterLab version %s from packaged module %s'%(dep, mod))
-                        break
-
     indent = "        "
     subindent = indent + "    "
     entry_msg = indent + u"{} has entry point in manifest"
@@ -559,7 +543,7 @@ def get_labextension_manifest_data_by_folder(folder):
 def get_labextension_manifest_data_by_name(name):
     """Get the manifest data for a given lab extension folder
     """
-    for exts in _labextension_dirs():
+    for exts in jupyter_path('labextensions'):
         full_dest = os.path.join(exts, name)
         if os.path.exists(full_dest):
             return get_labextension_manifest_data_by_folder(full_dest)
@@ -653,6 +637,7 @@ aliases = {
     "labextensions" : "InstallLabExtensionApp.labextensions_dir",
 }
 
+
 class InstallLabExtensionApp(BaseLabExtensionApp):
     """Entry point for installing JupyterLab extensions"""
     description = """Install JupyterLab extensions
@@ -892,16 +877,14 @@ class ListLabExtensionsApp(BaseLabExtensionApp):
     def list_labextensions(self):
         """List all the labextensions"""
         print("Known labextensions:")
-
+        seen = False
         for config_dir in jupyter_config_path():
+            config_dir = os.path.join(config_dir, CONFIG_DIR)
             cm = BaseJSONConfigManager(parent=self, config_dir=config_dir)
-            data = cm.get(CONFIG_NAME)
-            labextensions = (
-                data.setdefault("LabApp", {})
-                .setdefault("labextensions", {})
-            )
+            labextensions = cm.get('labextensions')
             if labextensions:
                 print(u'config dir: {}'.format(config_dir))
+                seen = True
             for name, config in sorted(labextensions.items()):
                 if isinstance(config, bool):
                     config = dict(enabled=config)
@@ -914,6 +897,8 @@ class ListLabExtensionsApp(BaseLabExtensionApp):
                               ))
                 if full_dest is not None:
                     validate_labextension_folder(name, full_dest, self.log)
+        if not seen:
+            print('....None found!')
 
     def start(self):
         """Perform the App's functions as configured"""
@@ -1053,18 +1038,6 @@ def _get_labextension_dir(user=False, sys_prefix=False, prefix=None, labextensio
     return labext
 
 
-def _labextension_dirs():
-    """The possible locations of labextensions.
-
-    Returns a list of known base extension locations
-    """
-    return [
-        pjoin(jupyter_data_dir(), u'labextensions'),
-        pjoin(ENV_JUPYTER_PATH[0], u'labextensions'),
-        pjoin(SYSTEM_JUPYTER_PATH[0], 'labextensions')
-    ]
-
-
 def _get_config_dir(user=False, sys_prefix=False):
     """Get the location of config files for the current context
 
@@ -1087,7 +1060,7 @@ def _get_config_dir(user=False, sys_prefix=False):
         labext = ENV_CONFIG_PATH[0]
     else:
         labext = SYSTEM_CONFIG_PATH[0]
-    return labext
+    return os.path.join(labext, CONFIG_DIR)
 
 
 def _get_labextension_metadata(module):
@@ -1112,29 +1085,31 @@ def _get_labextension_metadata(module):
     return m, labexts
 
 
-def _read_config_data(user=False, sys_prefix=False):
+def _read_config_data(section, user=False, sys_prefix=False):
     """Get the config for the current context
 
     Returns the string to the enviornment
 
     Parameters
     ----------
-
+    section: string
+        The section of config to read.
     user : bool [default: False]
         Get the user's .jupyter config directory
     sys_prefix : bool [default: False]
         Get sys.prefix, i.e. ~/.envs/my-env/etc/jupyter
     """
     config_dir = _get_config_dir(user=user, sys_prefix=sys_prefix)
-    config_man = BaseJSONConfigManager(config_dir=config_dir)
-    return config_man.get(CONFIG_NAME)
+    return BaseJSONConfigManager(config_dir=config_dir).get(section)
 
 
-def _write_config_data(data, user=False, sys_prefix=False, logger=None):
+def _write_config_data(section, data, user=False, sys_prefix=False, logger=None):
     """Update the config for the current context
 
     Parameters
     ----------
+    section: string
+        The section of data to update.
     data : object
         An object which can be accepted by ConfigManager.update
     user : bool [default: False]
@@ -1148,7 +1123,7 @@ def _write_config_data(data, user=False, sys_prefix=False, logger=None):
     if logger:
         logger.info(u"- Writing config: {}".format(config_dir))
     config_man = BaseJSONConfigManager(config_dir=config_dir)
-    config_man.update(CONFIG_NAME, data)
+    config_man.update(section, data)
 
 
 if __name__ == '__main__':
